@@ -15,11 +15,10 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import with_statement
 
 from os.path import join, dirname
-from cStringIO import StringIO
 
+from logilab.common.compat import StringIO
 from logilab.common.testlib import TestCase, unittest_main
 
 from logilab.common.changelog import ChangeLog
