@@ -16,7 +16,6 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with Logilab-Common.  If not, see <http://www.gnu.org/licenses/>.
 """unit tests for selectors mechanism"""
-from __future__ import with_statement
 
 import gc
 import logging
@@ -180,7 +179,7 @@ class RegistryStoreTC(TestCase):
         with prepended_syspath(self.datadir):
             store.register_objects([self.datapath('regobjects.py'),
                                     self.datapath('regobjects2.py')])
-        self.assertEqual(['zereg'], store.keys())
+        self.assertEqual(['zereg'], list(store.keys()))
         self.assertEqual(set(('appobject1', 'appobject2', 'appobject3')),
                          set(store['zereg']))
 
