@@ -20,24 +20,33 @@
 
 from __future__ import print_function
 
-from logilab.common.compat import StringIO
+import sys
+from io import StringIO
+buffers = [StringIO]
+if sys.version_info < (3, 0):
+    from cStringIO import StringIO as cStringIO
+    from StringIO import StringIO as pStringIO
+    buffers += [cStringIO, pStringIO]
+
 from logilab.common.ureports.nodes import *
 
 class WriterTC:
     def _test_output(self, test_id, layout, msg=None):
-        buffer = StringIO()
-        self.writer.format(layout, buffer)
-        got = buffer.getvalue()
-        expected = getattr(self, test_id)
-        try:
-            self.assertMultiLineEqual(got, expected)
-        except:
-            print('**** got for %s' % test_id)
-            print(got)
-            print('**** while expected')
-            print(expected)
-            print('****')
-            raise
+        for buffercls in buffers:
+            buffer = buffercls()
+            self.writer.format(layout, buffer)
+            got = buffer.getvalue()
+            expected = getattr(self, test_id)
+            try:
+                self.assertMultiLineEqual(got, expected)
+            except:
+                print('**** using a %s' % buffer.__class__)
+                print('**** got for %s' % test_id)
+                print(got)
+                print('**** while expected')
+                print(expected)
+                print('****')
+                raise
 
     def test_section(self):
         layout = Section('Section title',
